import { useNuxtApp, useRuntimeConfig } from "#imports";
export function useSegment(segment) {
  const $segment = segment ?? useNuxtApp().$segment;
  const config = useRuntimeConfig().public.segment;
  function shouldTrack() {
    return process.client && (process.env.NODE_ENV !== "development" || config.trackDevMode);
  }
  function identify(...args) {
    if (shouldTrack()) {
      return $segment.identify(...args);
    }
  }
  function page(...args) {
    if (shouldTrack()) {
      return $segment.page(...args);
    }
  }
  function track(...args) {
    if (shouldTrack()) {
      return $segment.track(...args);
    }
  }
  function trackSubmit(...args) {
    if (shouldTrack()) {
      return $segment.trackSubmit(...args);
    }
  }
  function trackClick(...args) {
    if (shouldTrack()) {
      return $segment.trackClick(...args);
    }
  }
  function trackLink(...args) {
    if (shouldTrack()) {
      return $segment.trackLink(...args);
    }
  }
  function raw(name, ...args) {
    if (shouldTrack()) {
      $segment[name](...args);
    }
  }
  return {
    $segment,
    identify,
    page,
    track,
    trackSubmit,
    trackClick,
    trackLink,
    raw
  };
}
